@@ -25,7 +25,7 @@
 
 void KickoffPlugin::registerTypes(const char *uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.pager"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.pager"));
 
     qmlRegisterType<PagerModel>(uri, 2, 0, "PagerModel");
 }
