@@ -19,58 +19,30 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
  ***************************************************************************/
 
-
 #ifndef AUTOSTART_H
 #define AUTOSTART_H
 
-#include <QPushButton>
-#include <QTreeWidget>
+#include <KQuickAddons/ConfigModule>
 
-#include <KCModule>
-#include <KFileItem>
+#include "autostartmodel.h"
 
-#include "ui_autostartconfig.h"
-#include "autostartitem.h"
-
-class Autostart: public KCModule
+class Autostart : public KQuickAddons::ConfigModule
 {
     Q_OBJECT
+    Q_PROPERTY(AutostartModel *model READ model CONSTANT)
 
 public:
-    explicit Autostart( QWidget* parent, const QVariantList&  );
+    explicit Autostart(QObject *parent, const QVariantList &);
     ~Autostart() override;
-    enum COL_TYPE { COL_NAME = 0, COL_COMMAND=1, COL_STATUS=2, COL_RUN=3 };
+
     void load() override;
     void save() override;
     void defaults() override;
 
-public Q_SLOTS:
-    void slotChangeStartup( ScriptStartItem *item, int index );
-
-protected:
-    void updateDesktopStartItem(DesktopStartItem *item, const QString &name, const QString &command, bool disabled, const QString &fileName);
-    void updateScriptStartItem(ScriptStartItem *item, const QString &name, const QString &command, AutostartEntrySource type, const QString &fileName);
-
-private Q_SLOTS:
-    void slotAddProgram();
-    void slotAddScript();
-    void slotRemoveCMD();
-    void slotEditCMD(QTreeWidgetItem*);
-    void slotEditCMD();
-    void slotSelectionChanged();
-    void slotItemClicked( QTreeWidgetItem *, int);
-    void slotAdvanced();
-    void slotRowInserted(const QModelIndex &parent, int first, int last);
-    void slotDatachanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles);
+    AutostartModel *model() const;
 
 private:
-    QModelIndex indexFromWidget(QTreeWidgetItem *widget) const;
-
     AutostartModel *m_model;
-    QTreeWidgetItem *m_programItem;
-    QTreeWidgetItem *m_scriptItem;
-
-    Ui_AutostartConfig *widget;
 };
 
 #endif
